==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property exact Header value sent by the client must match the specified value exactly.
 * @property prefix Header value sent by the client must begin with the specified characters.
 * @property range Object that specifies the range of numbers that the header value sent by the client must be included in.
 * @property regex Header value sent by the client must include the specified characters.
 * @property suffix Header value sent by the client must end with the specified characters.
 */
public data class GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs(
    public val exact: Output<String>? = null,
    public val prefix: Output<String>? = null,
    public val range: Output<GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgs>? = null,
    public val regex: Output<String>? = null,
    public val suffix: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs> {
    override fun toJava():
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 }))
            .prefix(prefix?.applyValue({ args0 -> args0 }))
            .range(range?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .regex(regex?.applyValue({ args0 -> args0 }))
            .suffix(suffix?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttp2RouteMatchHeaderMatchArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    private var prefix: Output<String>? = null

    private var range: Output<GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgs>? = null

    private var regex: Output<String>? = null

    private var suffix: Output<String>? = null

    /**
     * @param value Header value sent by the client must match the specified value exactly.
     */
    @JvmName("cobbkafedkdoxqby")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value Header value sent by the client must begin with the specified characters.
     */
    @JvmName("chucknudekpwirlb")
    public suspend fun prefix(`value`: Output<String>) {
        this.prefix = value
    }

    /**
     * @param value Object that specifies the range of numbers that the header value sent by the client must be included in.
     */
    @JvmName("bldgyofregauqgjd")
    public suspend fun range(`value`: Output<GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgs>) {
        this.range = value
    }

    /**
     * @param value Header value sent by the client must include the specified characters.
     */
    @JvmName("rnfkdfkmftwpplif")
    public suspend fun regex(`value`: Output<String>) {
        this.regex = value
    }

    /**
     * @param value Header value sent by the client must end with the specified characters.
     */
    @JvmName("vptiyijbvugybvrs")
    public suspend fun suffix(`value`: Output<String>) {
        this.suffix = value
    }

    /**
     * @param value Header value sent by the client must match the specified value exactly.
     */
    @JvmName("oxhoimrcxabcbhvo")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    /**
     * @param value Header value sent by the client must begin with the specified characters.
     */
    @JvmName("snjvqxtdtfwlnsvj")
    public suspend fun prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.prefix = mapped
    }

    /**
     * @param value Object that specifies the range of numbers that the header value sent by the client must be included in.
     */
    @JvmName("twuvlwbykaosnhhl")
    public suspend fun range(`value`: GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.range = mapped
    }

    /**
     * @param argument Object that specifies the range of numbers that the header value sent by the client must be included in.
     */
    @JvmName("novfyapgwphghtil")
    public suspend
    fun range(argument: suspend GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgsBuilder.() -> Unit) {
        val toBeMapped = GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.range = mapped
    }

    /**
     * @param value Header value sent by the client must include the specified characters.
     */
    @JvmName("nkmvylrnxcwqdbbj")
    public suspend fun regex(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regex = mapped
    }

    /**
     * @param value Header value sent by the client must end with the specified characters.
     */
    @JvmName("vtxyvsbthygyenrg")
    public suspend fun suffix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.suffix = mapped
    }

    internal fun build(): GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs =
        GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs(
            exact = exact,
            prefix = prefix,
            range = range,
            regex = regex,
            suffix = suffix,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property exact Header value sent by the client must match the specified value exactly.
 * @property prefix Header value sent by the client must begin with the specified characters.
 * @property range Object that specifies the range of numbers that the header value sent by the client must be included in.
 * @property regex Header value sent by the client must include the specified characters.
 * @property suffix Header value sent by the client must end with the specified characters.
 */
public data class GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs(
    public val exact: Output<String>? = null,
    public val prefix: Output<String>? = null,
    public val range: Output<GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgs>? = null,
    public val regex: Output<String>? = null,
    public val suffix: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 }))
            .prefix(prefix?.applyValue({ args0 -> args0 }))
            .range(range?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .regex(regex?.applyValue({ args0 -> args0 }))
            .suffix(suffix?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttp2RouteMatchHeaderMatchArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    private var prefix: Output<String>? = null

    private var range: Output<GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgs>? = null

    private var regex: Output<String>? = null

    private var suffix: Output<String>? = null

    /**
     * @param value Header value sent by the client must match the specified value exactly.
     */
    @JvmName("iwqcyklpiuejceef")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value Header value sent by the client must begin with the specified characters.
     */
    @JvmName("ihxeukoxmieqwpjp")
    public suspend fun prefix(`value`: Output<String>) {
        this.prefix = value
    }

    /**
     * @param value Object that specifies the range of numbers that the header value sent by the client must be included in.
     */
    @JvmName("ldvhsabmkoxpqejj")
    public suspend fun range(`value`: Output<GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgs>) {
        this.range = value
    }

    /**
     * @param value Header value sent by the client must include the specified characters.
     */
    @JvmName("edxygdboodnebbir")
    public suspend fun regex(`value`: Output<String>) {
        this.regex = value
    }

    /**
     * @param value Header value sent by the client must end with the specified characters.
     */
    @JvmName("bsfamqppcjpdntcy")
    public suspend fun suffix(`value`: Output<String>) {
        this.suffix = value
    }

    /**
     * @param value Header value sent by the client must match the specified value exactly.
     */
    @JvmName("ayyhstyoutbtgcer")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    /**
     * @param value Header value sent by the client must begin with the specified characters.
     */
    @JvmName("ybbahrqgmicwsoeh")
    public suspend fun prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.prefix = mapped
    }

    /**
     * @param value Object that specifies the range of numbers that the header value sent by the client must be included in.
     */
    @JvmName("wuwcsaxconqmblki")
    public suspend fun range(`value`: GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.range = mapped
    }

    /**
     * @param argument Object that specifies the range of numbers that the header value sent by the client must be included in.
     */
    @JvmName("pjxmctdnhwwdwbjy")
    public suspend fun range(argument: suspend GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgsBuilder.() -> Unit) {
        val toBeMapped = GatewayRouteSpecHttp2RouteMatchHeaderMatchRangeArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.range = mapped
    }

    /**
     * @param value Header value sent by the client must include the specified characters.
     */
    @JvmName("fiqrtukbibllsard")
    public suspend fun regex(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regex = mapped
    }

    /**
     * @param value Header value sent by the client must end with the specified characters.
     */
    @JvmName("jewxdxccdduggbwr")
    public suspend fun suffix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.suffix = mapped
    }

    internal fun build(): GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs =
        GatewayRouteSpecHttp2RouteMatchHeaderMatchArgs(
            exact = exact,
            prefix = prefix,
            range = range,
            regex = regex,
            suffix = suffix,
        )
}
